==> phoenix_widgets-1.17.3.tar.gz: lib/phoenix_list_group.dart <==
import 'package:flutter/material.dart';

class PhoenixListGroup extends StatelessWidget {
  const PhoenixListGroup({
    Key? key,
    required this.groupList,
    this.hideLastDivider = false,
  }) : super(key: key);
  final Map<String, List<DataHelper>> groupList;
  final bool hideLastDivider;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        /// Generate group menu title
        for (int rootIndex = 0; rootIndex < groupList.keys.length; rootIndex++)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.all(8),
                child: Text(
                  groupList.keys.elementAt(rootIndex),
                  style: const TextStyle(
                    color: Color(0xff75767A),
                    fontWeight: FontWeight.normal,
                    fontSize: 14,
                  ),
                ),
              ),

              /// Generate child in group menu
              for (int index = 0;
                  index < groupList.values.elementAt(rootIndex).length;
                  index++)
                if (groupList.values.elementAt(rootIndex)[index].isVisible)
                  Column(
                    children: [
                      TextButton(
                        style: TextButton.styleFrom(
                          padding: const EdgeInsets.symmetric(horizontal: 8),
                          disabledForegroundColor: const Color(0xff67C1BF),
                        ),
                        onPressed: groupList.values
                            .elementAt(rootIndex)[index]
                            .onPressed,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Text(
                              groupList.values
                                      .elementAt(rootIndex)[index]
                                      .title ??
                                  "",
                              style: const TextStyle(
                                color: Color(0xFF212124),
                                fontSize: 16,
                                fontWeight: FontWeight.normal,
                              ),
                            ),
                            const Icon(
                              Icons.chevron_right_rounded,
                              color: Color(0xff75767A),
                            ),
                          ],
                        ),
                      ),
                      if (!hideLastDivider ||
                          (index !=
                              groupList.values.elementAt(rootIndex).length -
                                  1)) ...[
                        const Divider(
                          color: Color(0xffD9DBE0),
                          thickness: 1,
                          height: 0,
                        )
                      ]
                    ],
                  ),
              const SizedBox(height: 24),
            ],
          )
      ],
    );
  }
}

class DataHelper {
  final String? title;
  final String? desc;
  bool isSelected;
  final String? iconPath;
  final IconData? icon;
  final String? url;
  final String? type;
  final int? id;
  VoidCallback? onPressed;
  bool isVisible;
  final Color? color;

  DataHelper({
    this.title,
    this.desc,
    this.isSelected = false,
    this.iconPath,
    this.icon,
    this.url,
    this.type,
    this.id,
    this.onPressed,
    this.isVisible = true,
    this.color,
  });
}

==> phoenix_widgets-1.17.4.tar.gz: lib/phoenix_list_group.dart <==
import 'package:flutter/material.dart';

class PhoenixListGroup extends StatelessWidget {
  const PhoenixListGroup({
    Key? key,
    required this.groupList,
    this.hideLastDivider = false,
    this.titlePadding = const EdgeInsets.all(8),
  }) : super(key: key);

  final Map<String, List<DataHelper>> groupList;
  final bool hideLastDivider;
  final EdgeInsets titlePadding;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: groupList.keys.map((rootKey) {
        final visibleChildren =
            groupList[rootKey]?.where((data) => data.isVisible).toList();

        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: titlePadding,
              child: Text(
                rootKey,
                style: const TextStyle(
                  color: Color(0xff75767A),
                  fontWeight: FontWeight.normal,
                  fontSize: 14,
                ),
              ),
            ),
            Column(
              children: [
                for (var data in visibleChildren!)
                  Column(
                    children: [
                      TextButton(
                        style: TextButton.styleFrom(
                          padding: const EdgeInsets.symmetric(horizontal: 8),
                          disabledForegroundColor: const Color(0xff67C1BF),
                        ),
                        onPressed: data.onPressed,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Text(
                              data.title ?? "",
                              style: const TextStyle(
                                color: Color(0xFF212124),
                                fontSize: 16,
                                fontWeight: FontWeight.normal,
                              ),
                            ),
                            const Icon(
                              Icons.chevron_right_rounded,
                              color: Color(0xff75767A),
                            ),
                          ],
                        ),
                      ),
                      if (!hideLastDivider || data != visibleChildren.last)
                        const Divider(
                          color: Color(0xffD9DBE0),
                          thickness: 1,
                          height: 0,
                        ),
                    ],
                  ),
              ],
            ),
            if (!hideLastDivider) ...[
              const SizedBox(height: 24),
            ]
          ],
        );
      }).toList(),
    );
  }
}

class DataHelper {
  final String? title;
  final String? desc;
  bool isSelected;
  final String? iconPath;
  final IconData? icon;
  final String? url;
  final String? type;
  final int? id;
  VoidCallback? onPressed;
  bool isVisible;
  final Color? color;

  DataHelper({
    this.title,
    this.desc,
    this.isSelected = false,
    this.iconPath,
    this.icon,
    this.url,
    this.type,
    this.id,
    this.onPressed,
    this.isVisible = true,
    this.color,
  });
}
